<?php
/*
Plugin Name: Multi-X Bar - Simple Links Pack
Plugin URI: http://www.icprojects.net/multi-x-bar-simple-links.html
Description: This plugin adds iconic links on Multi-X Bar. Requires Multi-X Bar ver. 2.30 or higher.
Author: Ivan Churakov
Author URI: http://www.icprojects.net/about
Version: 1.15
*/
add_action('plugins_loaded', 'multixsimplelinks_init');

function multixsimplelinks_init() {
	if (class_exists('multix_class') && class_exists('multix_module')) {
		class multix_simple_link_general_options extends multix_module {
			function __construct() {
				if (function_exists('load_plugin_textdomain')) {
					load_plugin_textdomain('multix', false, dirname(plugin_basename(__FILE__)).'/languages/');
				}
				$this->module = array("id" => "simple_links_general", "title" => __('Simple Links General Settings', 'multix'), "settings" => true);
				$this->options = array (
					"number" => 0
				);
				$this->get_options();
				if (is_admin()) {
					add_action('multix_echo_options_general', array(&$this, 'admin_settings'));
					add_action('multix_save_options', array(&$this, 'save_options'));
				}
			}

			function admin_settings() {
				global $wpdb;
				echo '
							<table class="multix_useroptions">
								<tr>
									<th>'.__('Number of Simple Links', 'multix').':</th>
									<td>
										<select id="'.$this->field_name('number').'" name="'.$this->field_name('number').'" style="width: 60px;">';
				for ($i=0; $i<=10; $i++) {
					echo '
											<option value="'.$i.'"'.($i == $this->options['number'] ? ' selected="selected"' : '').'>'.$i.'</option>';
				}
				echo '
										</select>
										<br /><em>'.__('Select number of additional simple links.', 'multix').'</em>
									</td>
								</tr>
							</table>';
			}
				
			function save_options($active_modules = array()) {
				global $wpdb;
				$this->populate_options();
				$this->update_options();
			}
		}
		$multix_simple_link_general_options = new multix_simple_link_general_options();
	
		class multix_simple_link extends multix_module {
			var $number;
			function __construct($_number) {
				global $multix;
				if (function_exists('load_plugin_textdomain')) {
					load_plugin_textdomain('multix', false, dirname(plugin_basename(__FILE__)).'/languages/');
				}
				$this->number = $_number;
				$this->module = array("id" => "links-".$_number, "title" => __('Simple Link', 'multix').' #'.$_number, "settings" => true);
				
				$this->options = array (
					"label" => "Link #".$_number,
					"disable_label" => "off",
					"new_tab" => "off",
					"url" => "",
					"icon" => "fas fa-flag"
				);

				$this->get_options();
				
				add_filter('multix_check_options', array(&$this, 'check_options'), 10, 2);
				
				if (is_admin()) {
					add_action('multix_echo_options_box', array(&$this, 'admin_settings'));
					add_action('multix_save_options', array(&$this, 'save_options'));
				} else {
					add_action('multix_echo_module', array(&$this, 'echo_module'));
				}
				parent::__construct();
			}

			function check_options($_errors, $active_modules) {
				$errors = array();
				if (in_array($this->module['id'], $active_modules)) {
					if (strlen($this->options['label']) < 1) $errors[] = __('Link label must contain at least 1 characters', 'multix');
					else if (strlen($this->options['label']) > 32) $errors[] = __('Link label is too long (max 32 characters allowed)', 'multix');
					if (!preg_match('|^http(s)?://[a-z0-9-]+(.[a-z0-9-]+)*(:[0-9]+)?(/.*)?$|i', $this->options['url']) || empty($this->options['url'])) $errors[] = __('Invalid Simple Link URL', 'multix');
				}
				return array_merge($_errors, $errors);
			}

			function admin_settings() {
				global $wpdb, $multix;
				$reflector = new ReflectionClass('multix_class');
				$multix_path = $reflector->getFileName();
				if ($multix_path !== false) $multix_images_url = plugins_url('/images/', $multix_path);
				else $multix_images_url = WP_PLUGIN_URL.'/multix/images/';
				echo '
					<div class="postbox multix-invisible" id="multix-settings-'.$this->module['id'].'">
						<h3 class="hndle" style="cursor: default;"><span>'.__('Simple Link', 'multix').' #'.$this->number.' '.__('Settings', 'multix').'</span></h3>
						<div class="inside">
							<table class="multix_useroptions">
								<tr>
									<th>'.__('Link label', 'multix').':</th>
									<td><input type="text" id="'.$this->field_name('label').'" name="'.$this->field_name('label').'" value="'.htmlspecialchars($this->options['label'], ENT_QUOTES).'" class="widefat"><br /><em>'.__('Enter the label of the link.', 'multix').'</em></td>
								</tr>
								<tr>
									<th>'.__('Disable link label', 'multix').':</th>
									<td>
										<input type="checkbox" id="'.$this->field_name('disable_label').'" name="'.$this->field_name('disable_label').'" '.($this->options['disable_label'] == "on" ? 'checked="checked"' : '').'"> '.__('Do not display link label (icon only)', 'multix').'
										<br /><em>'.__('Please tick checkbox if you want to display icon only.', 'multix').'</em>
									</td>
								</tr>';
				if ($multix->options['fa_enable'] == 'on') {
					echo '
								<tr>
									<th>'.__('Link icon', 'multix').':</th>
									<td>
										<span id="'.$this->field_name('icon_image').'" class="multix-icon multix-icon-active" title="'.__('Icons', 'multix').'" onclick="jQuery(\'#'.$this->field_name('icon_set').'\').slideToggle(300);"><i class="'.$this->options['icon'].'"></i></span><br />
										<div id="'.$this->field_name('icon_set').'" class="multix-icon-set">';
					if ($multix->options['fa_solid_enable'] == 'on') {
						foreach ($multix->fa_solid as $value) {
							echo '<span class="multix-icon'.($this->options['icon'] == 'fas fa-'.$value ? ' multix-icon-active' : '').'" title="'.$value.'" onclick="multix_seticon(this, \''.$this->field_name('icon').'\');"><i class="fas fa-'.$value.'"></i></span>';
						}
					}
					if ($multix->options['fa_regular_enable'] == 'on') {
						foreach ($multix->fa_regular as $value) {
							echo '<span class="multix-icon'.($this->options['icon'] == 'far fa-'.$value ? ' multix-icon-active' : '').'" title="'.$value.'" onclick="multix_seticon(this, \''.$this->field_name('icon').'\');"><i class="far fa-'.$value.'"></i></span>';
						}
					}
					if ($multix->options['fa_brands_enable'] == 'on') {
						foreach ($multix->fa_brands as $value) {
							echo '<span class="multix-icon'.($this->options['icon'] == 'fab fa-'.$value ? ' multix-icon-active' : '').'" title="'.$value.'" onclick="multix_seticon(this, \''.$this->field_name('icon').'\');"><i class="fab fa-'.$value.'"></i></span>';
						}
					}
					echo '
										</div>
										<input type="hidden" name="'.$this->field_name('icon').'" id="'.$this->field_name('icon').'" value="'.$this->options['icon'].'">
										<em>'.__('Select desired module icon.', 'multix').'</em>
									</td>
								</tr>';
				}
				echo '
								<tr>
									<th>'.__('Link URL', 'multix').':</th>
									<td><input type="text" id="'.$this->field_name('url').'" name="'.$this->field_name('url').'" value="'.htmlspecialchars($this->options['url'], ENT_QUOTES).'" class="widefat"><br /><em>'.__('Enter the URL of the link.', 'multix').'</em></td>
								</tr>
								<tr>
									<th>'.__('New tab/window', 'multix').':</th>
									<td>
										<input type="checkbox" id="'.$this->field_name('new_tab').'" name="'.$this->field_name('new_tab').'" '.($this->options['new_tab'] == "on" ? 'checked="checked"' : '').'"> '.__('Open link in new tab/window', 'multix').'
										<br /><em>'.__('Please tick checkbox if you want to open link in new tab/window.', 'multix').'</em>
									</td>
								</tr>
							</table>
							<div class="alignright">
							<input type="submit" class="multix_button button-primary" name="submit" value="'.__('Update Settings', 'multix').'">
							</div>
						</div>
					</div>';
			}
				
			function save_options($active_modules = array()) {
				global $wpdb;
				if (in_array($this->module['id'], $active_modules)) {
					$this->populate_options();
					if (isset($_POST[$this->field_name('disable_label')])) $this->options['disable_label'] = "on";
					else $this->options['disable_label'] = "off";
					if (isset($_POST[$this->field_name('new_tab')])) $this->options['new_tab'] = "on";
					else $this->options['new_tab'] = "off";
					$this->update_options();
				}
			}
				
			function echo_module($_moduleid) {
				if ($_moduleid == $this->module['id']) {
					if ($this->options['disable_label'] == "on") echo '<a id="multix_simple_link_'.$this->number.'_link"'.($this->options['new_tab'] == "on" ? ' target="_blank"' : '').' class="multix_iconlink multix_right" href="'.$this->options['url'].'" title="'.esc_attr($this->options['label']).'"><i class="fa '.$this->options['icon'].'"></i></a>';
					else echo '<a id="multix_simple_link_'.$this->number.'_link"'.($this->options['new_tab'] == "on" ? ' target="_blank"' : '').' class="multix_boxedlink multix_right" href="'.$this->options['url'].'" title="'.esc_attr($this->options['label']).'"><i class="fa '.$this->options['icon'].'"></i><span>'.esc_attr($this->options['label']).'</span></a>';
				}
			}
		}
		if (!defined('MULTIX_VERSION') || MULTIX_VERSION < 2.3) {
			add_action('admin_notices', 'multixsimplelink_oldmultix');
		} else {
			$multix_simple_links = array();
			for($i=1; $i<=$multix_simple_link_general_options->options['number']; $i++) {
				$multix_simple_links[] = new multix_simple_link($i);
			}
		}
	} else {
		add_action('admin_notices', 'multixsimplelink_nomultix');
	}
}

function multixsimplelink_nomultix() {
	echo '
		<div class="updated"><p>'.__('Please activate <strong>Multi-X Bar</strong> plugin to use <strong>Multi-X Bar - Simple Links Pack</strong>. Get your copy of Multi-X Bar <strong><a href="http://codecanyon.net/item/multix-bar/3741886?ref=ichurakov">here</a></strong>.', 'multix').'</p></div>';
}
function multixsimplelink_oldmultix() {
	echo '
		<div class="updated"><p>'.__('<strong>Multi-X Bar - Simple Links Pack</strong> requires <strong>Multi-X Bar</strong> ver <strong>2.30</strong> or higher to be installed. Get latest copy of Multi-X Bar <strong><a href="http://codecanyon.net/item/multix-bar/3741886?ref=ichurakov">here</a></strong>.', 'multix').'</p></div>';
}

?>